@@ -1,11 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ca">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="766"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>MX Data i Hora</translation>
     </message>
@@ -15,290 +13,273 @@
         <translation>Tanca</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="39"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Ajuda </translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="71"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Aplica</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="91"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Quant a...</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="111"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Data i Hora</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="177"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>H:mm:ss</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="261"/>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>Rellotge de maquinari</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="267"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Eines del rellotge de maquinari</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="273"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Obté informació del rellotge de maquinari i el mostra en un quadre a sota.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="276"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Llegeix el rellotge de maquinari</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="286"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Aplica correccions automàtiques de la deriva del rellotge de maquinari.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="289"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>Ajusta la deriva</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="312"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>Transfereix l&apos;hora</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="318"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Ajusta immediatament el rellotge de Sistema a la mateixa hora que el rellotge de maquinari.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="321"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Rellotge de maquinari a rellotge del Sistema</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="331"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>Defineix instantàniament el rellotge de maquinari a la mateixa hora que el rellotge de Sistema.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="334"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Rellotge del Sistema a rellotge de maquinari</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="344"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Actualitza el factor de deriva pel rellotge de maquinari en ajutar-lo.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="347"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>Actualitza la deriva</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="357"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Fus horari per al rellotge de maquinari</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="363"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>Hora Local</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="366"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>Local</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="373"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Hora Universal Coordinada (o Greenwich Meridian Time)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="376"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="404"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>Hora de la xarxa</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="501"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>Mou avall l&apos;opció seleccionada</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="444"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>Mou amunt l&apos;opció seleccionada</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="434"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>Elimina l&apos;opció actual de la llista</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="410"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>Afegeix una opció a la llista</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="420"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Actualitza automàticament el rellotge del Sistema amb servidors NTP:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="488"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Actualitza automàticament el rellotge del Sistema amd servidors NTP.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="491"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>Actualitza ara</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="454"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>Llista de servidors NTP a usar.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="470"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>Tipus </translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="475"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>Adreça</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="480"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>Opcions </translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="348"/>
+        <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>Llegint...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="365"/>
+        <location filename="../datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>Ajustant...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>Rellotge de Sistema</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="392"/>
+        <location filename="../datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>L&apos;hora %1 s&apos;ha transferit al %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="395"/>
+        <location filename="../datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>No es pot transferir l&apos;hora %1 al %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="772"/>
-        <source>%1 License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../datetime.cpp" line="352"/>
         <source>Updating...</source>
-        <translation type="vanished">Actualitzant...</translation>
+        <translation>Actualitzant...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="449"/>
+        <location filename="../datetime.cpp" line="365"/>
         <source>The system clock was updated successfully.</source>
         <translation>El rellotge del Sistema s&apos;ha actualitzat amb èxit.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="452"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock could not be updated.</source>
         <translation>No es pot actualitzar el rellotge del Sistema.</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="369"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
-        <translation type="vanished">Cap dels servidors de la llista està activat en aquest moment.</translation>
+        <translation>Cap dels servidors de la llista està activat en aquest moment.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="765"/>
+        <location filename="../datetime.cpp" line="603"/>
         <source>About MX Date &amp; Time</source>
         <translation>Quant a MX Data i Hora</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="767"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>Version: </source>
         <translation>Versió: </translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="768"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Programa amb IGU per ajustar la data i l&apos;hora a MX Linux</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="771"/>
+        <location filename="../datetime.cpp" line="607"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="608"/>
+        <location filename="../datetime.cpp" line="622"/>
         <source>License</source>
-        <translation type="vanished">Llicència</translation>
+        <translation>Llicència</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="609"/>
         <source>Changelog</source>
-        <translation type="vanished">Registre de canvis</translation>
+        <translation>Registre de canvis</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="610"/>
         <source>Cancel</source>
-        <translation type="vanished">Cancel·la</translation>
+        <translation>Cancel·la</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="636"/>
         <source>&amp;Close</source>
-        <translation type="vanished">Tan&amp;ca </translation>
+        <translation>Tan&amp;ca </translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="776"/>
+        <location filename="../datetime.cpp" line="654"/>
         <source>MX Date &amp; Time Help</source>
         <translation>Ajuda de MX Data i Hora</translation>
     </message>
 </context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../about.cpp" line="52"/>
-        <source>License</source>
-        <translation type="unfinished">Llicència</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="53"/>
-        <location filename="../about.cpp" line="61"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Registre de canvis</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="73"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">Tan&amp;ca </translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
