@@ -1,11 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="fi">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
 <context>
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="766"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>MX päivämäärä &amp; kellonaika</translation>
     </message>
@@ -15,290 +13,273 @@
         <translation>Sulje</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="39"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Ohje</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="71"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Hyväksy</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="91"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Tietoja...</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="111"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Päivämäärä &amp;&amp; kellonaika</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="177"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>t:mm:ss</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="261"/>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>Laitteistokellonaika</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="267"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Työkalut laitteistokellolle</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="273"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Nouda tietoja laitteistokellosta ja esitä ne allaolevassa laatikossa.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="276"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Lue laitteistokellonaika</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="286"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
-        <translation>Toteuta järjestelmälliset kasautumakorjaukset laitteistokelloon.</translation>
+        <translation>Korjaa laitteistokellon ajoitusta systemaattisesti.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="289"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>Kasautumien säätö</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="312"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>Kellonajan siirto</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="318"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
-        <translation>Aseta järjestelmäkello täsmäämään tämänhetkisen ajan kanssa välittömästi suhteessa laitteistokelloon. </translation>
+        <translation>Aseta järjestelmäkello välittömästi vastaamaan laitteistokellon rekisteröimää nykyistä aikaa.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="321"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Laitteistokellosta järjestelmäkelloon</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="331"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
-        <translation>Aseta laitteistokello täsmäämään tämänhetkisen ajan kanssa välittömästi suhteessa järjestelmäkelloon.</translation>
+        <translation>Aseta laitteistokello välittömästi vastaamaan järjestelmäkellon rekisteröimää nykyistä aikaa.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="334"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Järjestelmäkellosta laitteistokelloon</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="344"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Päivitä laitteistokellon kasautumamääre asetettaessa.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="347"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>Päivitä kasautuma</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="357"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Laitteistokellon aikavyöhyke</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="363"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>Paikallinen aika</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="366"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>Paikallinen</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="373"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Koordinoitu yleisaika UCT (tai GMT Greenwich Meridian Time)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="376"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="404"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>Verkon kellonaika</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="501"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>Siirrä valittua kohdetta alas</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="444"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>Siirrä valittua kohdetta ylös</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="434"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>Poista tämänhetkinen kohde luettelosta</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="410"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>Lisää kohde luetteloon</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="420"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
-        <translation>Päivitä järjestelmäkello NTP-palvelimien kanssa automaattisesti:</translation>
+        <translation>Päivitä järjestelmäkello automaattisesti NTP-palvelimilla:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="488"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Päivitä järjestelmäkello NTP-palvelimien kanssa välittömästi:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="491"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>Päivitä heti</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="454"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>Käytettävissä olevien NTP-palvelimien luettelo.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="470"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>Tyyppi</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="475"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>Osoite</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="480"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="348"/>
+        <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>Lukee...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="365"/>
+        <location filename="../datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>Mukauttaa...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>Järjestelmäkello</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="392"/>
+        <location filename="../datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>%1 aika siirrettiin %2 :een.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="395"/>
+        <location filename="../datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>%1 aikaa ei voitu siirtää %2 :een</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="772"/>
-        <source>%1 License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../datetime.cpp" line="352"/>
         <source>Updating...</source>
-        <translation type="vanished">Päivittää...</translation>
+        <translation>Päivittää...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="449"/>
+        <location filename="../datetime.cpp" line="365"/>
         <source>The system clock was updated successfully.</source>
         <translation>Järjestelmäkello päivitettiin onnistuneesti.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="452"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock could not be updated.</source>
         <translation>Järjestelmäkelloa ei voitu päivittää.</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="369"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
-        <translation type="vanished">Yksikään luettelon NTP-palvelimista ei ole tällä hetkellä päälle kytkettynä.</translation>
+        <translation>Yksikään luettelon NTP-palvelimista ei ole tällä hetkellä päälle kytkettynä.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="765"/>
+        <location filename="../datetime.cpp" line="603"/>
         <source>About MX Date &amp; Time</source>
         <translation>Tietoja MX:n päivämäärästä &amp; kellonajasta</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="767"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>Version: </source>
         <translation>Versio: </translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="768"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Graafinen ohjelma kellonajan ja päivämäärän asettamiseen MX Linux:issa.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="771"/>
+        <location filename="../datetime.cpp" line="607"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="608"/>
+        <location filename="../datetime.cpp" line="622"/>
         <source>License</source>
-        <translation type="vanished">Lisenssi</translation>
+        <translation>Lisenssi</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="609"/>
         <source>Changelog</source>
-        <translation type="vanished">Muutosloki</translation>
+        <translation>Muutosloki</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="610"/>
         <source>Cancel</source>
-        <translation type="vanished">Peru</translation>
+        <translation>Peru</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="636"/>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;Sulje</translation>
+        <translation>&amp;Sulje</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="776"/>
+        <location filename="../datetime.cpp" line="654"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX:n päivämäärän &amp; kellonajan apuopas</translation>
     </message>
 </context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../about.cpp" line="52"/>
-        <source>License</source>
-        <translation type="unfinished">Lisenssi</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="53"/>
-        <location filename="../about.cpp" line="61"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Muutosloki</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="73"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Sulje</translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
