@@ -1,11 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="he_IL">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he_IL">
 <context>
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="766"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>התאריך והשעה של MX</translation>
     </message>
@@ -15,290 +13,273 @@
         <translation>סגירה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="39"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>עזרה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="71"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>החלה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="91"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>על אודות...</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="111"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>תאריך &amp;ושעה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="177"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>H:mm:ss</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="261"/>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>שעון חומרה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="267"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>כלי שעון חומרה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="273"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>לקבל מידע משעון החומרה ולהציג אותו בתיבה שלהלן.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="276"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>קריאה שעון החומרה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="286"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>החלת תיקוני סטייה מערכתיים לשעון החומרה.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="289"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>התאמת סטייה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="312"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>העברת זמן</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="318"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>לכוון את שעון המערכת מול השעה הנוכחית שנרשמה בשעון החומרה מיידית.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="321"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>שעון החומרה לשעון המערכת</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="331"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>לכוון את שעון החומרה מול השעה הנוכחית שנרשמה בשעון המערכת מיידית.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="334"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>שעון המערכת לשעון החומרה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="344"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>לעדכן את מקדם הסטייה לשעון החומרה בעת הכיוון.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="347"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>עדכון הסטייה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="357"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>אזור הזמן לשעון החומרה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="363"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>שעה מקומית</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="366"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>מקומי</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="373"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>זמן אוניברסלי מתואם (או שעון גריניץ׳)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="376"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="404"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>שעון</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="501"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>העברת הפריט הנבחר למטה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="444"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>העברת הפריט הנבחר למעלה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="434"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>הסרת הפריט הנוכחי מהרשימה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="410"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>הוספת פריט לרשימה</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="420"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>לעדכן את שעון המערכת אוטומטית משרתי NTP:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="488"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>לעדכן את שעון המערכת מיידית מול שרתי NTP.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="491"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>לעדכן כעת</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="454"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>רשימת שרתי NTP לשימוש.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="470"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>סוג</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="475"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>כתובת</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="480"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>אפשרויות</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="348"/>
+        <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>מתבצעת קריאה…</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="365"/>
+        <location filename="../datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>מתבצע כוונון…</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>שעון מערכת</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="392"/>
+        <location filename="../datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>השעה %1 הועברה אל %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="395"/>
+        <location filename="../datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>לא ניתן להעביר את השעה %1 אל %2.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="772"/>
-        <source>%1 License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../datetime.cpp" line="352"/>
         <source>Updating...</source>
-        <translation type="vanished">מתבצע עדכון…</translation>
+        <translation>מתבצע עדכון…</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="449"/>
+        <location filename="../datetime.cpp" line="365"/>
         <source>The system clock was updated successfully.</source>
         <translation>שעון המערכת עודכן בהצלחה.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="452"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock could not be updated.</source>
         <translation>שעון המערכת לא עודכן.</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="369"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
-        <translation type="vanished">אף אחד משרתי ה־NTP ברשימה מופעלים.</translation>
+        <translation>אף אחד משרתי ה־NTP ברשימה מופעלים.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="765"/>
+        <location filename="../datetime.cpp" line="603"/>
         <source>About MX Date &amp; Time</source>
         <translation>על אודות התאריך והשעה של MX</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="767"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>Version: </source>
         <translation>גירסה:</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="768"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>תכנית חזותית להגדרת השעה והתאריך ב־MX Linux.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="771"/>
+        <location filename="../datetime.cpp" line="607"/>
         <source>Copyright (c) MX Linux</source>
         <translation>זכויות היוצרים (c) שמורות ל־MX Linux</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="608"/>
+        <location filename="../datetime.cpp" line="622"/>
         <source>License</source>
-        <translation type="vanished">רשיון</translation>
+        <translation>רשיון</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="609"/>
         <source>Changelog</source>
-        <translation type="vanished">יומן שינויים</translation>
+        <translation>יומן שינויים</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="610"/>
         <source>Cancel</source>
-        <translation type="vanished">ביטול</translation>
+        <translation>ביטול</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="636"/>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;סגירה</translation>
+        <translation>&amp;סגירה</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="776"/>
+        <location filename="../datetime.cpp" line="654"/>
         <source>MX Date &amp; Time Help</source>
         <translation>עזרה בנושא התאריך והשעה של MX</translation>
     </message>
 </context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../about.cpp" line="52"/>
-        <source>License</source>
-        <translation type="unfinished">רשיון</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="53"/>
-        <location filename="../about.cpp" line="61"/>
-        <source>Changelog</source>
-        <translation type="unfinished">יומן שינויים</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="73"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">&amp;סגירה</translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
