@@ -1,11 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
 <context>
     <name>MXDateTime</name>
     <message>
         <location filename="../datetime.ui" line="20"/>
-        <location filename="../datetime.cpp" line="766"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>MX dátum és idő</translation>
     </message>
@@ -15,290 +13,273 @@
         <translation>Bezárás</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="39"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Súgó</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="71"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Alkalmazás</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="91"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Névjegy</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="111"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>Dátum &amp;&amp; idő</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="177"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>Ó:pp:mm</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="261"/>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>A számítógép órája</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="267"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Eszközök a számítógép órájához</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="273"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Információk beszerzése a számítógép órájától és megjelenítés lentebb.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="276"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>A számítógép órájának olvasása</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="286"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Adott rendszer szerinti igazítás alkalmazása a számítógép órájára.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="289"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>Igazítás állítása</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="312"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>Idő áttöltése</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="318"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Az operációs rendszer órájának beállítása a számítógép órája szerinti aktuális időhöz.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="321"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Számítógép órája a rendszer órájába</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="331"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>A számítógép órájának beállítása az operációs rendszer órája szerinti aktuális időhöz.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="334"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Rendszer órája a számítógép órájába</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="344"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Az igazítási érték frissítése a számítógép órájának beállításához.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="347"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>Igazítás frissítése</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="357"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Időzóna a számítógép órájához</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="363"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>Helyi idő</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="366"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>Helyi</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="373"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Egyetemesen koordinált idő (UTC) (vagy greenwichi meridián idő)</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="376"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="404"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>Hálózati idő</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="501"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>A kijelölt elem mozgatása lefelé</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="444"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>A kijelölt elem mozgatása felfelé</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="434"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>A kijelölt elem eltávolítása a listáról</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="410"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>Egy elem hozzáadása a listához</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="420"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>A rendszer órájának automatikus beállítása NTP szerverrel:</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="488"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Azonnal beállítja a rendszer óráját NTP szerverek segítségével.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="491"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>Beállítás most</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="454"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>A használandó NTP kiszolgálók.</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="470"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>Típus</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="475"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>Cím</translation>
     </message>
     <message>
-        <location filename="../datetime.ui" line="480"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>Beállítások</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="348"/>
+        <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>Olvasás...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="365"/>
+        <location filename="../datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>Igazítás...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="379"/>
-        <location filename="../datetime.cpp" line="386"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>Rendszeróra</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="392"/>
+        <location filename="../datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>A %1 szerinti idő átmásolásra került a %2 értékébe.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="395"/>
+        <location filename="../datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>A %1 szerinti idő átmásolásra nem sikerült a %2 értékébe.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="772"/>
-        <source>%1 License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../datetime.cpp" line="352"/>
         <source>Updating...</source>
-        <translation type="vanished">Frissítés...</translation>
+        <translation>Frissítés...</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="449"/>
+        <location filename="../datetime.cpp" line="365"/>
         <source>The system clock was updated successfully.</source>
         <translation>A rendszeróra frissítése sikeres.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="452"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock could not be updated.</source>
         <translation>A rendszeróra frissítése nem sikerült.</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="369"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
-        <translation type="vanished">A listán szereplő egyik NTP kiszolgáló sincs engedélyezve.</translation>
+        <translation>A listán szereplő egyik NTP kiszolgáló sincs engedélyezve.</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="765"/>
+        <location filename="../datetime.cpp" line="603"/>
         <source>About MX Date &amp; Time</source>
         <translation>Az MX dátum és idő alkalmazásról</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="767"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>Version: </source>
         <translation>Verzió:</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="768"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Grafikus felület a dátum és idő beállítására az MX Linuxban</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="771"/>
+        <location filename="../datetime.cpp" line="607"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="608"/>
+        <location filename="../datetime.cpp" line="622"/>
         <source>License</source>
-        <translation type="vanished">Licenc</translation>
+        <translation>Licenc</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="609"/>
         <source>Changelog</source>
-        <translation type="vanished">Változások listája</translation>
+        <translation>Változások listája</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="610"/>
         <source>Cancel</source>
-        <translation type="vanished">Mégsem</translation>
+        <translation>Mégsem</translation>
     </message>
     <message>
+        <location filename="../datetime.cpp" line="636"/>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;Bezárás</translation>
+        <translation>&amp;Bezárás</translation>
     </message>
     <message>
-        <location filename="../datetime.cpp" line="776"/>
+        <location filename="../datetime.cpp" line="654"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX dátum és idő segítség</translation>
     </message>
 </context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../about.cpp" line="52"/>
-        <source>License</source>
-        <translation type="unfinished">Licenc</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="53"/>
-        <location filename="../about.cpp" line="61"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Változások listája</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="73"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Bezárás</translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
